==> nextcloud-15.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/systemtags/l10n/zh_TW.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "標籤",
    "Update" : "套用",
    "Create" : "新增",
    "Select tag…" : "選擇標籤",
    "Tagged files" : "已標籤檔案",
    "Select tags to filter by" : "依照選擇的標籤篩選",
    "No tags found" : "找不到標籤",
    "Please select tags to filter by" : "請選擇標籤以篩選",
    "No files found for the selected tags" : "沒有與選擇的標籤相符的檔案",
    "Added system tag {systemtag}" : "已加入系統標籤 {systemtag}",
    "Added system tag %1$s" : "已加入系統標籤 %1$s",
    "%1$s added system tag %2$s" : "%1$s已加入系統標籤 %2$s",
    "{actor} added system tag {systemtag}" : "{actor} 已加入系統標籤 {systemtag}",
    "Removed system tag {systemtag}" : "已移除系統標籤 {systemtag}",
    "Removed system tag %1$s" : "已移除系統標籤 %1$s",
    "%1$s removed system tag %2$s" : "%1$s 已移除系統標籤 %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} 已移除系統標籤 {systemtag}",
    "You created system tag %1$s" : "您新增了系統標籤 %1$s",
    "You created system tag {systemtag}" : "您新增了系統標籤 {systemtag}",
    "%1$s created system tag %2$s" : "%1$s 新增了系統標籤 %2$s",
    "{actor} created system tag {systemtag}" : "{actor} 新增了系統標籤 {systemtag}",
    "You deleted system tag %1$s" : "您刪除了系統標籤 %1$s",
    "You deleted system tag {systemtag}" : "您刪除了系統標籤 {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s刪除了系統標籤 %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} 刪除了系統標籤 {systemtag}",
    "You updated system tag %2$s to %1$s" : "您更新了系統標籤 %2$s 為 %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "您更新了系統標籤 {oldsystemtag} 為 {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s 更新了系統標籤 %3$s 為 %2$s",
    "%s (restricted)" : "%s （受限）",
    "%s (invisible)" : "%s （隱藏）",
    "<strong>System tags</strong> for a file have been modified" : "一個檔案的<strong>系統標籤</strong>已經被修改",
    "Collaborative tags" : "協作標籤",
    "Select tag …" : "選擇標籤…",
    "Name" : "名稱",
    "Public" : "公開",
    "Restricted" : "受限",
    "Invisible" : "隱藏",
    "Delete" : "移除",
    "Reset" : "重設",
    "No files in here" : "沒有任何檔案",
    "No entries found in this folder" : "在此資料夾中沒有任何項目",
    "Size" : "大小",
    "Modified" : "修改時間",
    "Create and edit collaborative tags. These tags affect all users." : "新增和編輯協作標籤，這些標籤將影響所有使用者"
},
"nplurals=1; plural=0;");

==> nextcloud-19.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/systemtags/l10n/zh_TW.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "標籤",
    "Update" : "套用",
    "Create" : "新增",
    "Select tag…" : "選擇標籤",
    "Added system tag {systemtag}" : "已加入系統標籤 {systemtag}",
    "Added system tag %1$s" : "已加入系統標籤 %1$s",
    "%1$s added system tag %2$s" : "%1$s已加入系統標籤 %2$s",
    "{actor} added system tag {systemtag}" : "{actor} 已加入系統標籤 {systemtag}",
    "Removed system tag {systemtag}" : "已移除系統標籤 {systemtag}",
    "Removed system tag %1$s" : "已移除系統標籤 %1$s",
    "%1$s removed system tag %2$s" : "%1$s 已移除系統標籤 %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} 已移除系統標籤 {systemtag}",
    "You created system tag %1$s" : "您新增了系統標籤 %1$s",
    "You created system tag {systemtag}" : "您新增了系統標籤 {systemtag}",
    "%1$s created system tag %2$s" : "%1$s 新增了系統標籤 %2$s",
    "{actor} created system tag {systemtag}" : "{actor} 新增了系統標籤 {systemtag}",
    "You deleted system tag %1$s" : "您刪除了系統標籤 %1$s",
    "You deleted system tag {systemtag}" : "您刪除了系統標籤 {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s刪除了系統標籤 %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} 刪除了系統標籤 {systemtag}",
    "You updated system tag %2$s to %1$s" : "您更新了系統標籤 %2$s 為 %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "您更新了系統標籤 {oldsystemtag} 為 {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s 更新了系統標籤 %3$s 為 %2$s",
    "%s (restricted)" : "%s （受限）",
    "%s (invisible)" : "%s （隱藏）",
    "<strong>System tags</strong> for a file have been modified" : "一個檔案的<strong>系統標籤</strong>已經被修改",
    "Collaborative tags" : "協作標籤",
    "Tagged files" : "已標籤檔案",
    "Select tags to filter by" : "依照選擇的標籤篩選",
    "No tags found" : "找不到標籤",
    "Please select tags to filter by" : "請選擇標籤以篩選",
    "No files found for the selected tags" : "沒有與選擇的標籤相符的檔案",
    "Select tag …" : "選擇標籤…",
    "Create a new tag" : "建立新標籤",
    "Name" : "名稱",
    "Public" : "公開",
    "Restricted" : "受限",
    "Invisible" : "隱藏",
    "Delete" : "移除",
    "Reset" : "重設",
    "No files in here" : "沒有任何檔案",
    "No entries found in this folder" : "在此資料夾中沒有任何項目",
    "Size" : "大小",
    "Modified" : "修改時間"
},
"nplurals=1; plural=0;");
